Arthur de Jong

Open Source / Free Software developer

summaryrefslogtreecommitdiffstats
path: root/stdnum/nl/btw.py
diff options
context:
space:
mode:
authorArthur de Jong <arthur@arthurdejong.org>2012-02-26 12:10:38 +0100
committerArthur de Jong <arthur@arthurdejong.org>2012-02-26 12:10:38 +0100
commit902a6569bf90aa37a185a2e099b913b39b6db3f7 (patch)
treec9894909466a10c906d851902319d152ce6048db /stdnum/nl/btw.py
parent907e41082fe4d05556d402dc30376fce9f32d344 (diff)
ensure that the module docstrings are in a somewhat more usable format
git-svn-id: http://arthurdejong.org/svn/python-stdnum/python-stdnum@165 9dea7c4f-944c-4273-ac1a-574ede026edc
Diffstat (limited to 'stdnum/nl/btw.py')
-rw-r--r--stdnum/nl/btw.py6
1 files changed, 5 insertions, 1 deletions
diff --git a/stdnum/nl/btw.py b/stdnum/nl/btw.py
index 77731a0..eea0cce 100644
--- a/stdnum/nl/btw.py
+++ b/stdnum/nl/btw.py
@@ -17,7 +17,11 @@
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301 USA
-"""Module for handling Dutch VAT (BTW) numbers.
+"""BTW-nummer (Omzetbelastingnummer, the Dutch VAT number).
+
+The BTW-nummer is the Dutch number for VAT. It consists of a RSIN or BSN
+followed by a B and two digits that identify the unit within the
+organisation (usually 01).
>>> is_valid('004495445B01')
True